#[repr(C)]pub enum ContainerAttributeDependencyKind {
None = 0,
UnnamedContainer = 1,
NamedContainer = 2,
}Expand description
Whether this container uses attr() references and if so whether or not this is a named or unnamed container query. Used for determining which kind of restyle hint we need when traversing invalidation.
Variants
None = 0
This container does not use attr() references.
UnnamedContainer = 1
This unnamed container uses attr() references.
NamedContainer = 2
This named container uses attr() references.
Implementations
Sourceimpl ContainerAttributeDependencyKind
impl ContainerAttributeDependencyKind
Sourcepub fn element_container_dependency_kind<E: TElement>(
element: E,
local_name: &LocalName,
stylist: &Stylist,
) -> Self
pub fn element_container_dependency_kind<E: TElement>( element: E, local_name: &LocalName, stylist: &Stylist, ) -> Self
A named container that uses attr needs to invalidate all descendants that are affected by style container queries. If we only have an unnamed container or no attribute dependencies we keep looking for a condition that would require us to invalidate more.