pub type AttrReferenceSet = PrecomputedHashSet<LocalName>;Expand description
A set of attribute names used for invalidation of attr() inside style container queries.
Aliased Type
pub struct AttrReferenceSet { /* private fields */ }pub type AttrReferenceSet = PrecomputedHashSet<LocalName>;A set of attribute names used for invalidation of attr() inside style container queries.
pub struct AttrReferenceSet { /* private fields */ }